"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.handler = exports.builder = exports.desc = exports.command = void 0;
const ansi_colors_1 = __importDefault(require("ansi-colors"));
const vueHandler_1 = require("../handlers/vueHandler");
const constants_1 = require("../lib/constants");
const validator_1 = require("../lib/validator");
exports.command = "vue [targetFilePaths...]";
exports.desc = "Suppress TS errors in Vue files";
const builder = (yargs) => yargs
    .options(constants_1.DEFAULT_OPTIONS)
    .positional("targetFilePaths", {
    array: true,
    type: "string",
    demandOption: true,
    description: "Path to the target vue file, which can be set with the glob pattern. eg: 'src/**/*.vue'",
})
    .check(validator_1.tsconfigExists)
    .check(validator_1.isVueFiles);
exports.builder = builder;
const handler = async (argv) => {
    const { targetFilePaths, tsconfigPath, commentType, errorCode } = argv;
    const insertedCommentCount = await (0, vueHandler_1.vueHandler)({
        targetFilePaths,
        tsconfigPath,
        commentType,
        errorCode,
    });
    console.log("\nCompleted 🎉");
    console.log("suppress errors: " + ansi_colors_1.default.green(insertedCommentCount.toString()));
    process.exit(0);
};
exports.handler = handler;
