"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.tsHandler = void 0;
const ts_morph_1 = require("ts-morph");
const progressBar_1 = require("../lib/progressBar");
const suppressTsErrors_1 = require("../lib/suppressTsErrors");
const tsHandler = ({ tsconfigPath, commentType, errorCode, }) => {
    // Get all project files
    const project = new ts_morph_1.Project({ tsConfigFilePath: tsconfigPath });
    const sourceFiles = project.getSourceFiles();
    // Initialize progress bar
    const progressBar = (0, progressBar_1.generateProgressBar)();
    progressBar.start(sourceFiles.length, 0);
    // Rewrite source in ts/tsx file with source with comment
    let insertedCommentCount = 0;
    sourceFiles.forEach((sourceFile) => {
        const { text: textWithComment, count: insertedCommentCountPerFile } = (0, suppressTsErrors_1.suppressTsErrors)({
            sourceFile,
            commentType,
            withErrorCode: errorCode,
        });
        if (insertedCommentCountPerFile > 0) {
            sourceFile.replaceWithText(textWithComment);
            sourceFile.saveSync();
            insertedCommentCount += insertedCommentCountPerFile;
        }
        progressBar.increment();
    });
    progressBar.stop();
    return insertedCommentCount;
};
exports.tsHandler = tsHandler;
