"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const vitest_1 = require("vitest");
const extractTypeScriptFromVue_1 = require("../extractTypeScriptFromVue");
(0, vitest_1.describe)("extractScriptFromVue", () => {
    vitest_1.it.each([
        {
            source: `
      <template>
        <div class="hello">hello</div>
      </template>

      <script lang="ts">
        import Vue from 'vue'

        export Vue.extend({
          name: 'HelloWorld',
          data() {
            return {
              message: 'Hello World!'
            }
          }
        })
      </script>

      <style>
        .hello {
          color: red;
        }
      </style>
      `,
            expected: `
        import Vue from 'vue'

        export Vue.extend({
          name: 'HelloWorld',
          data() {
            return {
              message: 'Hello World!'
            }
          }
        })
      `,
        },
        {
            source: `
      <template>
        <div class="hello">hello</div>
      </template>

      <script>
        import Vue from 'vue'

        export Vue.extend({
          name: 'HelloWorld',
          data() {
            return {
              message: 'Hello World!'
            }
          }
        })
      </script>

      <style>
        .hello {
          color: red;
        }
      </style>
      `,
            expected: "",
        },
    ])("extractScript", ({ source, expected }) => {
        const result = (0, extractTypeScriptFromVue_1.extractTypeScriptFromVue)(source);
        (0, vitest_1.expect)(result).toEqual(expected);
    });
});
